# frozen_string_literal: true

module DietaryDsl
  # Módulo que agrupa las constantes y funciones útiles respecto a la base de datos BEDCA
  module BEDCA
    ATTRIBUTES = {
      # Identificador
      # 12
      'f_id' => :id,
      # Nombre en español
      # Arroz
      'f_ori_name' => :nombre,
      # Nombre en inglés
      # Rice
      'f_eng_name' => :name,
      # Nombre científico
      # Oryza sativa
      'sci_name' => :scientific_name,
      # A0696 A0730 A0814 A0960 A1240 A1290 B1322 C0155 E0131 F0003 G0003 H0003 H0398 J0003 K0004 M0128 N0036 P0024...
      'langual' => :langual,
      # Código en la base de datos EFSA, http://iufost.org/databases, https://www.efsa.europa.eu/en/efsajournal/pub/1970
      # A001D
      'foodexcode' => :foodexcode,
      # 11
      'mainlevelcode' => :mainlevelcode,
      # Código de primer nivel de FoodEx
      # A000J
      'codlevel1' => :codlevel1,
      # Nombre del primer nivel de FoodEx
      # Grains and grain-based products
      'namelevel1' => :namelevel1,
      # 29
      'codsublevel' => :codsublevel,
      # Código de segundo nivel de FoodEx
      # A000K
      'codlevel2' => :codlevel2,
      # Nombre del primer nivel de FoodEx
      # Grains and grain-based products
      'namelevel2' => :namelevel2,
      # ???
      # null
      'f_des_esp' => :f_des_esp,
      # ???
      # null
      'f_des_ing' => :f_des_ing,
      # ???
      # URL de la imagen
      'photo' => :photo,
      # ???
      # null
      'edible_portion' => :edible_portion,
      # Origen de la información
      # BEDCA2
      'f_origen' => :f_origen,
      # Valores nutricionales del alimento
      # Array de componentes
      'foodvalue' => :foodvalue,

      # =======================================================================
      # Components
      # =======================================================================
      # Identificador
      # 53
      'c_id' => :id,
      # Nombre en español
      # carbohidratos
      'c_ori_name' => :nombre,
      # Nombre en inglés
      # carbohydrate
      'c_eng_name' => :name,
      # ???
      # CHO
      'eur_name' => :eur_name,
      # ???
      # 2
      'componentgroup_id' => :componentgroup_id,
      # Glosario del componente en español
      # Este componente es uno de losmacronutrientes e incluye todos los hidratos de carbono
      'glos_esp' => :glos_esp,
      # Glosario del componente en español
      # null
      'glos_ing' => :glos_ing,
      # Descripción del grupo de componentes en español
      # Hidratos de carbono
      'cg_descripcion' => :categoria,
      # Descripción del grupo de componentes en inglés
      # Carbohydrate components
      'cg_description' => :cg_description,
      # Cantidad de materia que contiene el elemento consultado
      # 86
      'best_location' => :cantidad,
      # Unidad de medida
      # g
      'v_unit' => :unidad,
      # ???
      # W
      'moex' => :moex,
      # ???
      # null
      'stdv' => :stdv,
      # ???
      # null
      'min' => :min,
      # ???
      # null
      'max' => :max,
      # ???
      # null
      'v_n' => :v_n,
      # Identificador de unidad de medición
      # g
      'u_id' => :u_id,
      # Descripción de la unidad de medición en español
      # gramos
      'u_descripcion' => :u_descripcion,
      # Descripción de la unidad de medición en inglés
      # gram
      'u_description' => :u_description,
      # ???
      # AR
      'value_type' => :value_type,
      # Descripción del tipo de valor en español
      # como aparece en la fuente
      'vt_descripcion' => :vt_descripcion,
      # Descripción del tipo de valor en inglés
      # as reported
      'vt_description' => :vt_description,
      # ???
      # W
      'mu_id' => :mu_id,
      # ???
      # por 100 g de porción comestible
      'mu_descripcion' => :mu_descripcion,
      # ???
      # per 100 g edible portion
      'mu_description' => :mu_description,
      # ???
      # 258
      'ref_id' => :ref_id,
      # ???
      # null
      'citation' => :citation,
      # ???
      # tabla de composición de alimentos
      'at_descripcion' => :at_descripcion,
      # ???
      # food composition table
      'at_description' => :at_description,
      # ???
      # libro
      'pt_descripcion' => :pt_descripcion,
      # ???
      # book
      'pt_description' => :pt_description,
      # ???
      # 344
      'method_id' => :method_id,
      # ???
      # tipo de método no conocido
      'mt_descripcion' => :mt_descripcion,
      # ???
      # method type not known
      'mt_description' => :mt_description,
      # ???
      # Extraccion: Alicuotas del alimento (entre 5 y 30 g) dependiendo del color son...
      'm_descripcion' => :m_descripcion,
      # ???
      # null
      'm_description' => :m_description,
      # ???
      # Método no conocido (Moreiras)
      'm_nom_esp' => :m_nom_esp,
      # ???
      # Unknown method  (Moreiras)
      'm_nom_ing' => :m_nom_ing,
      # ???
      # Metodo analitico o de cálculo no conocido
      'mhd_descripcion' => :mhd_descripcion,
      # ???
      # Analytical or calculation method not known
      'mhd_description' => :mhd_description
    }.freeze
  end
end
