# frozen_string_literal: true

require 'uri'
require 'net/http'
require 'builder'
require 'active_support/all'
require 'dietary_dsl/bedca_api/constants'
require 'dietary_dsl/bedca_api/food_value'
require 'dietary_dsl/bedca_api/food_values'
require 'pp'

module DietaryDsl
  # Parte de la clase que presenta sus datos
  class Food
    def kcal
      @data[:groups][:proximales][:energia_total][:cantidad]
        .gsub(/.+kJ/, '')
        .to_f * 0.238846
    end

    def to_s
      tables = @data[:groups]
               .map do |(_key, group)|
                 group.to_table
               end
               .join("\n")

      <<~TO_MARKDOWN
        # #{self[:nombre]}

        > #{self[:scientific_name]}

        ## Distribución de la Energía total

        Proteínas: #{@general_values[:proteina_total]}
        Grasas: #{@general_values[:grasa_total]}
        Carbohidratos: #{@general_values[:carbohidratos]}
        Alcohol: #{@general_values[:alcohol]}

        ## Información de composición (por 100 g de porción comestible)

        #{tables}
      TO_MARKDOWN
    end
  end
end
