# frozen_string_literal: true

require 'dietary_dsl/bedca_api/constants'

module DietaryDsl
  # Clase que representa un tipo de valor nutricional y sus datos
  class FoodValues
    include BEDCA
    include Enumerable

    def initialize(title, values)
      @title = title
      @data = arr_to_hash(parse_values(values), COMPONENTS) { |value| value[:id] }
    end

    def [](key)
      @data[key]
    end

    def each
      @data.each { |i| yield i }
    end

    def parse_values(values)
      values
        .map { |value| FoodValue.new(value) }
        .uniq { |value| value[:id] }
    end

    def to_s
      JSON.pretty_generate(@data).gsub(':', ' =>') + "\n"
    end

    def inspect
      to_s
    end

    def to_table
      <<~TO_TABLE
        ### #{@title}

        | Componente | Valor | Unidad |
        |------------|-------|--------|
        #{@data.map { |_key, value| value.to_table }.join("\n")}
      TO_TABLE
    end
  end
end
