# frozen_string_literal: true

module DietaryDsl
  # Clase que representa un día completo, con los menús correspondientes para cada comida
  class Dia
    attr_reader :title

    include Enumerable

    def initialize(title = nil, &block)
      @title = title
      @menus = {}
      instance_eval(&block)
    end

    def [](key)
      @menus[key]
    end

    def kcal
      @menus.inject(0) do |sum, (_, menu)|
        sum + menu.kcal
      end
    end

    def each
      @menus.each { |i| yield i }
    end

    def desayuno(menu)
      @menus[:desayuno] = menu
    end

    def media_maniana(menu)
      @menus[:media_mañana] = menu
    end

    def almuerzo(menu)
      @menus[:almuerzo] = menu
    end

    def merienda(menu)
      @menus[:merienda] = menu
    end

    def cena(menu)
      @menus[:cena] = menu
    end
  end
end
