# frozen_string_literal: true

require 'dietary_dsl/dsl/alimento'

module DietaryDsl
  # Clase que representa un menú. Un menú se compone de distintos platos (entrantes, primeros platos, postres...)
  class Menu
    attr_reader :title

    include Enumerable

    def initialize(title, &block)
      @title = title
      @platos = []
      instance_eval(&block)
    end

    def [](key)
      @platos[key]
    end

    def each
      @platos.each { |i| yield i }
    end

    def plato(datos, options = {})
      return plato_single(datos) if datos.is_a?(Hash)
      @platos = @platos.push(plato: datos, racion: options[:racion])
    end

    def plato_single(datos)
      @platos = @platos.push(plato: DietaryDsl::Plato.new(datos[:food]) { alimento(datos) })
    end

    def racionar(plato, racion)
      if racion.nil?
        plato.kcal
      else
        ((racion.to.g * plato.kcal) / plato.masa.to.g)
      end
    end

    def kcal
      @platos.inject(0) do |sum, plato_y_cantidad|
        plato = plato_y_cantidad[:plato]
        racion = plato_y_cantidad[:racion]
        sum + racionar(plato, racion)
      end
    end
  end
end
