# frozen_string_literal: true

require 'dietary_dsl/bedca_api/food'

module DietaryDsl
  # Clase que representa un plato. Un plato es una comida específica, como pulpo a la gallega, o un potaje
  class Plato
    include Enumerable

    attr_reader :title

    def initialize(title, &block)
      @title = title
      @alimentos = []
      instance_eval(&block)
    end

    def [](key)
      @alimentos[key]
    end

    def each
      @alimentos.each { |i| yield i }
    end

    def alimento(datos)
      alimento = DietaryDsl::Alimento.new(datos[:food], datos)
      cantidad = datos[:cantidad]
      @alimentos = @alimentos.push food: alimento, cantidad: cantidad
    end

    def kcal
      @alimentos.inject(0) do |sum, item|
        cantidad = item[:cantidad]
        kilocalorias = item[:food].kcal

        is_mass = cantidad.instance_of? DietaryDsl::Masa
        gramos = cantidad.to.g if is_mass
        gramos = cantidad.to.cm3 unless is_mass
        kcal_totales = ((gramos * kilocalorias) / 100)
        sum + kcal_totales
      end
    end

    def kcal_por_cada(cantidad)
      (kcal * cantidad.to.g) / masa.to.g
    end

    def masa
      gr = @alimentos.inject(0) do |sum, item|
        is_mass = item[:cantidad].instance_of? DietaryDsl::Masa
        gramos = item[:cantidad].to.g if is_mass
        gramos = item[:cantidad].to.cm3 unless is_mass
        sum + gramos
      end

      DietaryDsl::Masa.new(gr)
    end

    def to_s
      alimentos = @alimentos
                  .map { |data| "* #{data[:food][:nombre]}" }
                  .join("\n")

      <<~OUTPUT
        #{@title}
        #{alimentos}
      OUTPUT
    end

    def single?
      @alimentos.length == 1
    end
  end
end
