# frozen_string_literal: true

require 'dietary_dsl/measures/measure'

module DietaryDsl
  # Esta clase nos permite representar unidades de masa, como gramos o kilogramos.
  class Masa < Measure
    def initialize(en_gramos)
      super(en_gramos)
      @small_postfix = 'g'
      @big_postfix = 'kg'
    end

    # Métodos de clase para instanciarlo

    def self.kg(number)
      DietaryDsl::Masa.new(number * 1000)
    end

    def self.g(number)
      DietaryDsl::Masa.new(number)
    end

    def self.rodaja(number)
      DietaryDsl::Masa.new(number * 20)
    end

    # Métodos para heredar

    def big
      kg
    end

    def small
      g
    end

    # Métodos de conversión

    def g
      @cantidad
    end

    def gramos
      g
    end

    def kg
      @cantidad / 1000
    end

    def kilogramos
      kg
    end

    # Métodos para multiplicar por un número, p.e. 3 * 10.g

    def coerce(arg)
      [Masa.new(arg), self]
    end

    def *(other)
      Masa.new(@cantidad * other.cantidad)
    end

    def +(other)
      Masa.new(@cantidad + other.cantidad)
    end
  end
end

# Se expande la clase Numeric con los nuevos métodos para la masa
class Numeric
  def g
    DietaryDsl::Masa.g(self)
  end

  def gramo
    g
  end

  def gramos
    g
  end

  def kg
    DietaryDsl::Masa.kg(self)
  end

  def kilogramo
    kg
  end

  def kilogramos
    kg
  end

  def rodaja
    DietaryDsl::Masa.rodaja(self)
  end

  def rodajas
    rodaja
  end
end
