# frozen_string_literal: true

require 'dietary_dsl/measures/measure'

module DietaryDsl
  # Esta clase nos permite representar unidades de volumen, como litros o cucharadas.
  class Volumen < Measure
    def initialize(en_ml)
      super(en_ml)
      @cantidad = cantidad.to_f
      @small_postfix = 'ml'
      @big_postfix = 'L'
    end

    def self.l(number)
      Volumen.new(number * 1000.0)
    end

    def self.ml(number)
      Volumen.new(number)
    end

    def self.cm3(number)
      Volumen.new(number)
    end

    def self.cucharada(number)
      Volumen.new(number * 15.0)
    end

    def self.vaso(number)
      Volumen.new(number * 200)
    end

    def self.chorrito(number)
      Volumen.new(number * 62.5)
    end

    # Métodos para heredar

    def big
      l
    end

    def small
      ml
    end

    def l
      @cantidad / 1000
    end

    def litros
      l
    end

    def cm3
      @cantidad
    end

    def ml
      @cantidad
    end

    def cucharadas
      @cantidad / 20
    end

    def coerce(arg)
      [Volumen.new(arg), self]
    end

    def *(other)
      Volumen.new(@cantidad * other.cantidad)
    end
  end
end

# Se expande la clase Numeric con los nuevos métodos para el volumen
class Numeric
  def l
    DietaryDsl::Volumen.l(self)
  end

  def litro
    l
  end

  def litros
    l
  end

  def ml
    DietaryDsl::Volumen.ml(self)
  end

  def mililitro
    ml
  end

  def mililitros
    ml
  end

  def cucharada
    DietaryDsl::Volumen.cucharada(self)
  end

  def cucharadas
    cucharada
  end

  def vaso
    DietaryDsl::Volumen.vaso(self)
  end

  def vasos
    vaso
  end

  def chorrito
    DietaryDsl::Volumen.chorrito(self)
  end

  def chorritos
    chorrito
  end
end
